%Run simulation model from script:
%Clear workspace and close figures
clear all
close all
clc

%First open and run script to generate transportation demands "Cargo" used
%as input for simulation model:
open('Cargo')
run('Cargo')

%simplify name of simulation model:
model = 'SimulationModel';
%Open simulation model:
open_system(model);

%Set simulation time
set_param(model, 'StopTime','336*200')

% RUN SIMULATION MODEL:
i=1; %Initialize row number for logging results
j=1; %Initialize colomn number for logging results

% RUN MODEL FOR DIFFERENT SPEEDS WHILE OPERABILITY OF SHIP-TO-SHIP CARGO
% TRANSFER OPERATION IS CONSTANT. UPDATE OPERABILITY AND REPEAT:
%Set lower limit, step-length, and upper limit for evaluated operability
for OP=0.8:0.1:1
    %Set lower limit, step-length, and upper limit for evaluated speeds_
    for V=2.5:0.2:3.5
        sim(model);
        % Log waiting time for mother and daughter for each simulation
        % (mean of all periods):
        WaitingTimeD(i,j)=mean(WaitingTimeDaughter.Data(5:end));
        Speed(j)=V;
        WaitingTimeM(i,j)=mean(WaitingTimeMother.Data(5:end));
        %(5:end) excludes four first meetings (cycle 1). Introduced to
        %avoid start-up effects.
        %Share of meetings on time:
        Reliability(i,j)=length(nonzeros(WaitingTimeDaughter.Data))/length(WaitingTimeDaughter.Data);
        
        %Separate each period when analyzing the results:
        h=1;
        %NB! Start on k=5 to exclude 4 first meeting (cycle 1). Introduced
        %to avoid start-up effects.
        %NB! excluding last four meetings as daughter vessel not always
        %finish all periods for low speeds.
        for k=5:4:length(WaitingTimeDaughter.Data) -4
            %Time spent waiting for mother vessel in each period:
            WaitingTimesDaughterP1(h)=WaitingTimeDaughter.Data(k);
            WaitingTimesDaughterP2(h)=WaitingTimeDaughter.Data(k+1);
            WaitingTimesDaughterP3(h)=WaitingTimeDaughter.Data(k+2);
            WaitingTimesDaughterP4(h)=WaitingTimeDaughter.Data(k+3);
            
           
            h=h+1;
        end
        %Average time spent waiting for mother vessel for each period:
        WaitingTimeDP1(i,j)=mean(WaitingTimesDaughterP1);
        WaitingTimeDP2(i,j)=mean(WaitingTimesDaughterP2);
        WaitingTimeDP3(i,j)=mean(WaitingTimesDaughterP3);
        WaitingTimeDP4(i,j)=mean(WaitingTimesDaughterP4);
        
        %Minimum time spent waiting for daughter vessel for each period:
        Min_WaitingTimeDP1(i,j)=min(WaitingTimesDaughterP1);
        Min_WaitingTimeDP2(i,j)=min(WaitingTimesDaughterP2);
        Min_WaitingTimeDP3(i,j)=min(WaitingTimesDaughterP3);
        Min_WaitingTimeDP4(i,j)=min(WaitingTimesDaughterP4);
        
        %Maximum time spent waiting for daughter vessel for each period:
        Max_WaitingTimeDP1(i,j)=max(WaitingTimesDaughterP1);
        Max_WaitingTimeDP2(i,j)=max(WaitingTimesDaughterP2);
        Max_WaitingTimeDP3(i,j)=max(WaitingTimesDaughterP3);
        Max_WaitingTimeDP4(i,j)=max(WaitingTimesDaughterP4);
        
        
        %Share of meetings that daughter vessel arrives before mother
        %vessel for each period:
        ReliabilityP1(i,j)=length(nonzeros(WaitingTimesDaughterP1))/length(WaitingTimesDaughterP1);
        ReliabilityP2(i,j)=length(nonzeros(WaitingTimesDaughterP2))/length(WaitingTimesDaughterP2);
        ReliabilityP3(i,j)=length(nonzeros(WaitingTimesDaughterP3))/length(WaitingTimesDaughterP3);
        ReliabilityP4(i,j)=length(nonzeros(WaitingTimesDaughterP4))/length(WaitingTimesDaughterP4);
        
        j=j+1;
    end
    j=1;
    i=i+1;
end

%RESULTS AVERAGE OF ALL PERIODS:
%Plot share of meetings daughter vessel arrives on time for all evaluated
%speeds and operabilities of ship-to-ship cargo transfer operation:
figure;
marker=['^','o','X'];
for i=1:1:3;
p=plot(Speed(1,:),Reliability(i,:));
p.Color='k';
p.LineWidth=1;
p.Marker=marker(i);
xlabel('Speed [knots]')
ylabel('Share of meetings on time')
axis([-inf inf 0.5 1])
hold on
end
legend('OP=0.8','OP=0.9','OP=1')

hold off  

%RESULTATER FROM EACH PERIOD (SEPARATED):
%Plot average time daughter vessel spend waiting for mother vessel for each period:
figure;
plot(Speed(1,:),WaitingTimeDP1(1,:),Speed(1,:),WaitingTimeDP1(2,:),Speed(1,:),WaitingTimeDP1(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
hold off
title('P1')
hold off

figure;
plot(Speed(1,:),WaitingTimeDP2(1,:),Speed(1,:),WaitingTimeDP2(2,:),Speed(1,:),WaitingTimeDP2(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
hold off
title('P2')
hold off

figure;
plot(Speed(1,:),WaitingTimeDP3(1,:),Speed(1,:),WaitingTimeDP3(2,:),Speed(1,:),WaitingTimeDP3(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
hold off
title('P3')
hold off

figure;
plot(Speed(1,:),WaitingTimeDP4(1,:),Speed(1,:),WaitingTimeDP4(2,:),Speed(1,:),WaitingTimeDP4(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
hold off
title('P4')
hold off

%Plot share of meetings that daughter vessel arrives at meeting point in
%time for all periods:
figure;
plot(Speed(1,:),ReliabilityP1(1,:),Speed(1,:),ReliabilityP1(2,:),Speed(1,:),ReliabilityP1(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
xlabel('Speed [knots]')
ylabel('Share of meetings on time')
title('P1')
axis([-inf inf 0 1])

figure;
plot(Speed(1,:),ReliabilityP2(1,:),Speed(1,:),ReliabilityP2(2,:),Speed(1,:),ReliabilityP2(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
xlabel('Speed [knots]')
ylabel('Share of meetings on time')
title('P2')
axis([-inf inf 0 1])

figure;
plot(Speed(1,:),ReliabilityP3(1,:),Speed(1,:),ReliabilityP3(2,:),Speed(1,:),ReliabilityP3(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
xlabel('Speed [knots]')
ylabel('Share of meetings on time')
title('P3')
axis([-inf inf 0 1])

figure;
plot(Speed(1,:),ReliabilityP4(1,:),Speed(1,:),ReliabilityP4(2,:),Speed(1,:),ReliabilityP4(3,:),'LineWidth',1)
legend('OP=0.8','OP=0.9','OP=1')
xlabel('Speed [knots]')
ylabel('Share of meetings on time')
title('P4')
axis([-inf inf 0 1])
